function [  ] = AutofindMicrogel( Pixelsize,Magnification,Sensitivity,Stepwidth,Covered_Radius,UnsicherheitspalteLokalisationsdatei )
%% Loading ThunderSTORM file and generate variables for the position of a localization and the uncertainty (generated script from fileimporter)
[FileName, PathName] = uigetfile('*.csv', 'Select .csv-Datei');
filepath=fullfile([PathName FileName]);
filename = num2str(filepath);
delimiter = ',';
startRow = 2;
formatSpec = '%f%f%f%f%f%f%f%s%f%f%[^\n\r]';
fileID = fopen(filename,'r');
dataArray = textscan(fileID, formatSpec, 'Delimiter', delimiter, 'EmptyValue' ,NaN,'HeaderLines' ,startRow-1, 'ReturnOnError', false);
fclose(fileID);
%frame = dataArray{:, 1};
xnm = dataArray{:, 2};
ynm = dataArray{:, 3};
%sigmanm = dataArray{:, 4};
%intensityphoton = dataArray{:, 5};
%offsetphoton = dataArray{:, 6};
%bkgstdphoton = dataArray{:, 7};
%chi2 = dataArray{:, 8};
uncertaintynm = dataArray{:, UnsicherheitspalteLokalisationsdatei};
%detections = dataArray{:, 10};
clearvars filename delimiter startRow formatSpec fileID dataArray ans;
%% Loading the reconstructed ThunderSTORM image
[FileName2, PathName2] = uigetfile('*.tif', 'Select .TIF-Datei');
filepath2=fullfile([PathName2 FileName2]);
img=imread(num2str(filepath2));
%% Assingn Postions from Pixelsize and magnification
x_min=0;
y_min=0;
x_max=1280*Pixelsize/Magnification;
y_max=1280*Pixelsize/Magnification;
%% Selecting points from the figure and counting localizations within the area
Position=[xnm,ynm];                                                         % wrapping up the positions to a matrix
Size_position=size(Position);                                               % counting how many localisations are generated
[centers, radii]=imfindcircles(img,[15 60],'Sensitivity',Sensitivity);      % using the image toolbox to find round objects ( microgels)
centers=centers*Pixelsize/Magnification;                                    % calculation of the center position in nm in the reconstructed image
radii=radii*Pixelsize/Magnification;                                        % calculation of the radius in the reconstructed image
%% show the reconstruceted image referse the y-axis and plot the centers of the microgels found be the toolbox
h=figure;
set(gca,'Ydir','reverse')
imagesc([x_min x_max], [y_min y_max],img)
axis([0 x_max 0 y_max])
axis square
hold on
plot(centers(:,1),centers(:,2),'m*','MarkerSize',5)
%% Predefine Variables for faster caluclation
Numbermicrogels=size(centers(:,1));                                        % Number of detected Microgels from the reconstructed image
Number_localizations=0;                                                    % Number of localizations at the beginnging
Numberwithinarea=[(0:Covered_Radius/Stepwidth)*Stepwidth]';                 % Number of localisations within a circle 
Numberwithinring=zeros(Numbermicrogels(1,1),Covered_Radius/Stepwidth);      % Number of localizations within a ring with the stepwidth width
Localisation_density=zeros(Numbermicrogels(1,1),Covered_Radius/Stepwidth);
Mean_localization_density=zeros(1,Covered_Radius/Stepwidth);
SEM_localization_density=zeros(1,Covered_Radius/Stepwidth);
uncertaintyarea=zeros(Numbermicrogels(1,1),Covered_Radius/Stepwidth);
uncertaintyring=zeros(Numbermicrogels(1,1),Covered_Radius/Stepwidth);
%%
for M=1:Numbermicrogels(1,1)
    
plot(centers(M,1)+Covered_Radius*sin(0:0.001:2*pi),centers(M,2)+Covered_Radius*cos(0:0.001:2*pi),'r','linewidth',2) % plotting the detected circels around the reconstructed microgels
%plot(centers(M,1)+radii(M)*sin(0:0.001:2*pi),centers(M,2)+radii(M)*cos(0:0.001:2*pi),'y','linewidth',2)
for k=2:Covered_Radius/Stepwidth+1
    localisationsuncertainty=zeros(1,Size_position(1,1));
for I=1:Size_position(1,1)
    if sqrt((Position(I,1)-centers(M,1))^2+(Position(I,2)-centers(M,2))^2)<=(k-1)*Stepwidth
        Number_localizations=Number_localizations+1;
        localisationsuncertainty(I)=uncertaintynm(I);
    end
end
    Numberwithinarea(k,2)=Number_localizations;    
    Numberwithinring(M,k-1)=Numberwithinarea(k,2)-Numberwithinarea(k-1,2);
    Localisation_density(M,k-1)=Numberwithinring(M,k-1)/(pi*((Stepwidth*(k-1))^2-(Stepwidth*(k-2))^2));
    uncertaintyarea(M,k)=sum(localisationsuncertainty);
    uncertaintyring(M,k)=uncertaintyarea(M,k)-uncertaintyarea(M,k-1); 
    Meanuncertaintyperring(M,k-1)=uncertaintyring(M,k)./ Numberwithinring(M,k-1);
    Number_localizations=0;
end
end
% Numberwithinring=Numberwithinring';
% Meanuncertaintyperring=Meanuncertaintyperring';
% set(h,'Units','Centimeters');
% pos = get(h,'Position');
% set(h,'PaperPositionMode','Auto','PaperUnits','Centimeters','PaperSize',[pos(3), pos(4)])
% print(h,'Overview','-dpdf','-r0')

h=figure;
radius=10:Stepwidth:Covered_Radius:
plot(radius,Localisation_density)
xlabel('Radius(nm)');
ylabel('Localization density (nm^{-2})')
set(h,'Units','Centimeters');
pos = get(h,'Position');
set(h,'PaperPositionMode','Auto','PaperUnits','Centimeters','PaperSize',[pos(3), pos(4)])
print(h,'Localisation_Densities','-dpdf','-r0')

for L=1:Covered_Radius/Stepwidth
    Mean_localization_density(L)=mean(Localisation_density(:,L));
    SEM_localization_density(L)=std(Localisation_density(:,L))./sqrt(length(Localisation_density(:,L)));
end

h=figure;
errorbar(radius,Mean_localization_density,SEM_localization_density)
xlabel('Radius(nm)');
ylabel('Localization density (nm^{-2})')
set(h,'Units','Centimeters');
pos = get(h,'Position');
set(h,'PaperPositionMode','Auto','PaperUnits','Centimeters','PaperSize',[pos(3), pos(4)])
print(h,'MEAN+SEM','-dpdf','-r0')

h=figure;
hist(radii)
set(h,'Units','Centimeters');
pos = get(h,'Position');
set(h,'PaperPositionMode','Auto','PaperUnits','Centimeters','PaperSize',[pos(3), pos(4)])
print(h,'Histograms_radii','-dpdf','-r0')
Localisation_density_to_3Dcalc=flipud(Localisation_density');
saveradius=radius';
radius_to_3Dcalc=flipud(saveradius);
save3Dcalc=[radius_to_3Dcalc, Localisation_density_to_3Dcalc];
savelocalisationdensity=[saveradius, Localisation_density'];
saveMEANSTD=[saveradius, Mean_localization_density', SEM_localization_density'];
save Localisation_Density.txt savelocalisationdensity -ascii -tabs
save Mean+SEM.txt  saveMEANSTD -ascii -tabs
save Radius_gel.txt radii -ascii -tabs
save Numberwithinring.txt Numberwithinring -ascii -tabs
save Meanuncertaintyperring.txt Meanuncertaintyperring -ascii -tabs
save Calc_input.txt save3Dcalc -ascii -tabs
end

